aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChristian Grothoff <grothoff@gnunet.org>2024-08-03 20:52:09 +0200
committerChristian Grothoff <grothoff@gnunet.org>2024-08-03 20:52:09 +0200
commit78bdd0933ca0df12ed0caeafb500d703da8e4398 (patch)
treeb5e4fa2fba685a946202e51383353011078c48d9
parent3ebfcf2d98460260c4638fe66430bdc479c78b80 (diff)
-make spell checker happy
-rw-r--r--src/backend/taler-merchant-httpd_private-get-instances-ID-kyc.c37
1 files changed, 16 insertions, 21 deletions
diff --git a/src/backend/taler-merchant-httpd_private-get-instances-ID-kyc.c b/src/backend/taler-merchant-httpd_private-get-instances-ID-kyc.c
index 9c215872..bc803b0b 100644
--- a/src/backend/taler-merchant-httpd_private-get-instances-ID-kyc.c
+++ b/src/backend/taler-merchant-httpd_private-get-instances-ID-kyc.c
@@ -480,21 +480,21 @@ ekr_finished (struct ExchangeKycRequest *ekr)
*
* @param ekr request context
* @param ks HTTP response details
* @param aks account KYC status details
* @return true if the operation was successful
*/
static bool
store_kyc_status (
const struct ExchangeKycRequest *ekr,
const struct TALER_EXCHANGE_KycStatus *ks,
- const struct TALER_EXCHANGE_AccountKycStatus *aks)
+ const struct TALER_EXCHANGE_AccountKycStatus *account_kyc_status)
{
unsigned int dl_cnt = 0;
- for (unsigned int i = 0; i<aks->limits_length; i++)
+ for (unsigned int i = 0; i<account_kyc_status->limits_length; i++)
{
const struct TALER_EXCHANGE_AccountLimit *limit
- = &aks->limits[i];
+ = &account_kyc_status->limits[i];
if (TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT ==
limit->operation_type)
@@ -506,10 +506,10 @@ store_kyc_status (
enum GNUNET_DB_QueryStatus qs;
unsigned int off = 0;
- for (unsigned int i = 0; i<aks->limits_length; i++)
+ for (unsigned int i = 0; i<account_kyc_status->limits_length; i++)
{
const struct TALER_EXCHANGE_AccountLimit *limit
- = &aks->limits[i];
+ = &account_kyc_status->limits[i];
struct TALER_MERCHANTDB_DepositLimits *dl
= &dls[off];
@@ -530,10 +530,10 @@ store_kyc_status (
GNUNET_TIME_timestamp_get (),
ks->hr.http_status,
ks->hr.ec,
- &aks->access_token,
+ &account_kyc_status->access_token,
dl_cnt,
dls,
- aks->aml_review,
+ account_kyc_status->aml_review,
false);
if (qs < 0)
{
@@ -564,30 +564,25 @@ exchange_check_cb (
switch (ks->hr.http_status)
{
case MHD_HTTP_OK:
- {
- const struct TALER_EXCHANGE_AccountKycStatus *aks;
-
- aks = &ks->details.ok;
- GNUNET_break (store_kyc_status (ekr,
- ks,
- aks));
- }
+ GNUNET_break (store_kyc_status (ekr,
+ ks,
+ &ks->details.ok));
break;
case MHD_HTTP_ACCEPTED:
{
- const struct TALER_EXCHANGE_AccountKycStatus *aks
+ const struct TALER_EXCHANGE_AccountKycStatus *account_kyc_status
= &ks->details.accepted;
char *kyc_url;
GNUNET_break (store_kyc_status (ekr,
ks,
- aks));
+ account_kyc_status));
{
char *ats;
ats = GNUNET_STRINGS_data_to_string_alloc (
- &aks->access_token,
- sizeof (aks->access_token));
+ &account_kyc_status->access_token,
+ sizeof (account_kyc_status->access_token));
GNUNET_asprintf (&kyc_url,
"%s/kyc-spa/%s",
ekr->exchange_url,
@@ -600,7 +595,7 @@ exchange_check_cb (
kc->pending_kycs,
GNUNET_JSON_PACK (
GNUNET_JSON_pack_data_auto ("access_token",
- &aks->access_token),
+ &account_kyc_status->access_token),
GNUNET_JSON_pack_string ("kyc_url",
kyc_url),
GNUNET_JSON_pack_string ("exchange_url",
@@ -480,21 +480,21 @@ ekr_finished (struct ExchangeKycRequest *ekr)
* @param ekr request context
* @param ks HTTP response details
- * @param aks account KYC status details
+ * @param account_kyc_status account KYC status details
* @return true if the operation was successful
*/